<?php

/**
 * @file
 * Contains \Drupal\ip_anon\Form\IpAnonSettings.
 */

namespace Drupal\ip_anon\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;

class IpAnonSettings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'ip_anon_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('ip_anon.settings');
    $config->set('policy', $form_state->getValue('policy'));
    foreach (Element::children($form['period']) as $variable) {
      $config->set($variable, $form_state->getValue($variable));
    }
    $config->save();
    parent::submitForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['ip_anon.settings'];
  }

  public function buildForm(array $form, \Drupal\Core\Form\FormStateInterface $form_state) {
    $config = $this->config('ip_anon.settings');
    $form['policy'] = [
      '#type' => 'radios',
      '#title' => t('Retention policy'),
      '#options' => [0 => t('Preserve IP addresses'), 1 => t('Anonymize IP addresses')],
      '#description' => t('This setting may be used to temporarily disable IP anonymization.'),
      '#default_value' => $config->get('policy'),
    ];
    $form['period'] = [
      '#type' => 'fieldset',
      '#title' => t('Retention period'),
      '#description' => t('IP addresses older than the retention period will be anonymized.'),
    ];
    $intervals = [
      0,
      30,
      60,
      120,
      180,
      300,
      600,
      900,
      1800,
      2700,
      3600,
      5400,
      7200,
      10800,
      21600,
      32400,
      43200,
      64800,
      86400,
      172800,
      259200,
      345600,
      604800,
      1209600,
      2419200,
      4838400,
      9676800,
      31536000,
    ];
    $options = array_combine($intervals, array_map([\Drupal::service('date.formatter'), 'formatInterval'], $intervals));
    module_load_include('inc', 'ip_anon');
    foreach (ip_anon_tables() as $table => $columns) {
      $form['period']["period_$table"] = [
        '#type' => 'select',
        '#title' => t('@table table', ['@table' => $table]),
        '#options' => $options,
        '#default_value' => $config->get("period_$table"),
      ];
    }
    return parent::buildForm($form, $form_state);
  }

}
